<?php
/************************************************************************
 * Mailer v0.2.1-FINAL                                Start: 08/03/2004 *
 * ===================                          Last change: 11/19/2005 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : task_functions.php                               *
 * -------------------------------------------------------------------- *
 * Short description : Special task functions                           *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Spezielle task-Funktionen                        *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2009 by Roland Haeder                           *
 * Copyright (c) 2009 - 2011 by Mailer Developer Team                   *
 * For more information visit: http://mxchange.org                      *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	die();
} // END - if

//
// The advanced overview shows detailed informations to your exchange script:
//  - Unconfirmed / locked accounts
//  - Mails waiting to be approved
//  - Open tasks
//  - Your own tasks
//  - ...
//
// @TODO Move all extension-dependent queries into filters
function outputAdvancedOverview (&$result_main) {
	// Init variables/arrays
	$EXTRAS = '';
	$OUT    = '';
	$WHATs  = array();
	$DESCRs = array();
	$TITLEs = array();

	// Chheck for new extensions and updates
	$jobsDone = outputStandardOverview($result_main);

	// Init SQLs
	initSqls();

	// Init content
	foreach (
		array(
			// Member accounts
			'confirmed_members','unconfirmed_members','locked_members','random_refid',
			// Tasks
			'update_tasks','new_tasks','closed_tasks','your_tasks','deleted_tasks','solved_tasks',
			// Mail orders
			'pending_mails','canceled_mails','send_emails',
			// Bonus mails
			'send_bonus_mails',
			// Purging
			'purged_mails','purged_bonus_mails'
		) as $entry) {
		// Set it to zero
		$content[$entry] = '0';
	} // END - foreach

	// Extension updates found
	$value = countSumTotalData(getCurrentAdminId(), 'task_system', 'id', 'assigned_admin', true, " AND `status`='NEW' AND `task_type`='EXTENSION_UPDATE'");

	if ($value > 0) {
		$content['update_tasks'] = '<a href="{%url=modules.php?module=admin&amp;what=list_task&amp;type=updates%}">' . $value . '</a>';
	} // END - if

	//
	// First check for all account status seperately
	//
	// Confirmed accounts
	$value = getTotalConfirmedUser();

	if ($value > 0) {
		$content['confirmed_members'] = '<a href="{%url=modules.php?module=admin&amp;what=list_user&amp;status=confirmed%}">' . $value . '</a>';
	} // END - if

	// Unconfirmed accounts
	$value = getTotalUnconfirmedUser();

	if ($value > 0) {
		$content['unconfirmed_members'] = '<a href="{%url=modules.php?module=admin&amp;what=list_user&amp;status=UNCONFIRMED%}">' . $value . '</a>';
	} // END - if

	// And locked accounts
	$value = getTotalLockedUser();
	if ($value > 0) {
		$content['locked_members'] = '<a href="{%url=modules.php?module=admin&amp;what=list_user&amp;status=locked%}">' . $value . '</a>';
	} // END - if

	if (isExtensionInstalledAndNewer('user', '0.3.4')) {
		// And random refid
		$value = getTotalRandomRefidUser();
		if ($value > 0) {
			$content['random_refid'] = '<a href="{%url=modules.php?module=admin&amp;what=list_user&amp;do=random_refid%}">' . $value . '</a>';
		} // END - if
	} // END - if

	//
	// Unassigned tasks
	//
	$value = countSumTotalData(0, 'task_system', 'id', 'assigned_admin', true, " AND `status` != 'DELETED'");

	if ($value > 0) {
		$content['new_tasks'] = '<a href="{%url=modules.php?module=admin&amp;what=list_task&amp;type=unassigned%}">' . $value . '</a>';
	} // END - if

	//
	// Closed tasks
	//
	$value = countSumTotalData('CLOSED', 'task_system', 'id', 'status', true);

	if ($value > 0) {
		$content['closed_tasks'] = '<a href="{%url=modules.php?module=admin&amp;what=list_task&amp;type=closed%}">' . $value . '</a>';
	} // END - if

	//
	// Deleted tasks
	//
	$value = countSumTotalData('DELETED', 'task_system', 'id', 'status', true);

	if ($value > 0) {
		$content['deleted_tasks'] = '<a href="{%url=modules.php?module=admin&amp;what=list_task&amp;type=deleted%}">' . $value . '</a>';
	} // END - if

	//
	// Solved tasks
	//
	$value = countSumTotalData('SOLVED', 'task_system', 'id', 'status', true, sprintf(" AND `assigned_admin`=%s", getCurrentAdminId()));

	if ($value > 0) {
		$content['solved_tasks'] = '<a href="{%url=modules.php?module=admin&amp;what=list_task&amp;type=solved%}">' . $value . '</a>';
	} // END - if

	//
	// Your tasks
	//
	$value = countSumTotalData(getCurrentAdminId(), 'task_system', 'id', 'assigned_admin', true, " AND `status`='NEW' AND task_type != 'EXTENSION_UPDATE'");

	if ($value > 0) {
		$content['your_tasks'] = '<a href="{%url=modules.php?module=admin&amp;what=list_task%}">' . $value . '</a>';
	} // END - if

	//
	// Mails waiting to be approved
	//
	$value = countSumTotalData('ADMIN', 'pool', 'id', 'data_type', true);

	if ($value > 0) {
		$content['pending_mails'] = '<a href="{%url=modules.php?module=admin&amp;what=unlock_emails%}">' . $value . '</a>';
	} // END - if

	//
	// Unfinished mail orders
	//
	$value = countSumTotalData('TEMP', 'pool', 'id', 'data_type', true);

	if ($value > 0) {
		$content['canceled_mails'] = '<a href="{%url=modules.php?module=admin&amp;what=email_details%}">' . $value . '</a>';
	} // END - if

	//
	// Sent mail orders
	//
	$value = countSumTotalData('SEND', 'pool', 'id', 'data_type', true);

	if ($value > 0) {
		$content['send_emails'] = '<a href="{%url=modules.php?module=admin&amp;what=email_archiv%}">' . $value . '</a>';
	} // END - if

	//
	// Autopurged mails
	//
	if (isExtensionActive('autopurge')) {
		// Get auto-purged mails
		$value = countSumTotalData('DELETED', 'pool', 'id', 'data_type', true);

		if ($value > 0) {
			$content['purged_mails'] = '<a href="{%url=modules.php?module=admin&amp;what=email_details%}">' . $value . '</a>';
		} // END - if

		//
		// Autopurged bonus mails
		//
		if (isExtensionInstalledAndNewer('bonus', '0.1.8')) {
			// Get auto-purged bonus mails
			$value = countSumTotalData('DELETED', 'bonus', 'id', 'data_type', true);

			if ($value > 0) {
				$content['purged_bonus_mails'] = '<a href="{%url=modules.php?module=admin&amp;what=email_details%}">' . $value . '</a>';
			} // END - if
		} elseif (isExtensionActive('bonus')) {
			$content['purged_bonus_mails'] = '{%message,ADMIN_EXTENSION_BONUS_OUTDATED=0.1.8%}';
		} else {
			$content['purged_bonus_mails'] = '<span class="bad">{--ADMIN_EXTENSION_BONUS_404--}</span>';
		}
	} else {
		$content['purged_bonus_mails'] = '<span class="bad">{--ADMIN_EXTENSION_AUTOPURGE_404--}</span>';
		$content['purged_mails'] = '<span class="bad">{--ADMIN_EXTENSION_AUTOPURGE_404--}</span>';
	}

	//
	// Sent bonus mails
	//
	if (isExtensionInstalledAndNewer('bonus', '0.1.8')) {
		// Get sent bonus mails (but not notifications)
		$value = countSumTotalData('SEND', 'bonus', 'id', 'data_type', true, " AND `is_notify`='N'");

		if ($value > 0) {
			$content['send_bonus_mails'] = '<a href="{%url=modules.php?module=admin&amp;what=email_details%}">' . $value . '</a>';
		} // END - if
	} elseif (isExtensionActive('bonus')) {
		$content['send_bonus_mails'] = '{%message,ADMIN_EXTENSION_BONUS_OUTDATED=0.1.8%}';
	} else {
		$content['send_bonus_mails'] = '{--ADMIN_EXTENSION_BONUS_404--}';
	}

	// Both extensions must be there
	if ((isExtensionActive('autopurge')) && (isExtensionActive('user'))) {
		// Start finding them...
		$EXCLUDE_LIST = '';

		// Check for more extensions
		// @TODO These can be rewritten to filter
		if (isValidUserId(getDefRefid()))              $EXCLUDE_LIST .= ' AND d.`userid` != {?def_refid?}';
		if (isExtensionActive('beg'))                  $EXCLUDE_LIST .= ' AND d.`userid` != {?beg_userid?}';
		if (isExtensionActive('bonus'))                $EXCLUDE_LIST .= ' AND d.`userid` != {?bonus_userid?}';
		if (isExtensionActive('doubler'))              $EXCLUDE_LIST .= ' AND d.`userid` != {?doubler_userid?}';
		if (isExtensionInstalledAndNewer('holiday', '0.1.3')) {
			// Recent ext-holiday found
			$EXCLUDE_LIST .= " AND d.`holiday_active`='N'";
		} // END - if

		// Check for all accounts
		addSql("SELECT
	d.userid, d.email, d.last_online
FROM
	`{?_MYSQL_PREFIX?}_user_data` AS d
WHERE
	d.`status`='CONFIRMED' AND
	(UNIX_TIMESTAMP() - d.`joined`) >= {?ap_inactive_since?} AND
	(UNIX_TIMESTAMP() - d.`last_online`) >= {?ap_inactive_since?} AND
	(UNIX_TIMESTAMP() - d.`ap_notified`) >= {?ap_inactive_since?}
".$EXCLUDE_LIST."
ORDER BY
	d.userid ASC");
		$WHATs[]  = 'list_autopurge';
		$DESCRs[] = '{--ADMIN_TASK_INACTIVE_AUTOPURGE--}';
		$TITLEs[] = '{--ADMIN_TASK_INACTIVE_AUTOPURGE_TITLE--}';
	}

	if ((isExtensionInstalledAndNewer('sql_patches', '0.3.4')) && (isExtensionActive('user'))) {
		// Check for accounts without referral
		addSql("SELECT `userid` FROM `{?_MYSQL_PREFIX?}_user_data` WHERE `refid`=0 OR `refid` IS NULL ORDER BY `userid` ASC");
		$DESCRs[] = '{--ADMIN_TASK_LIST_ACCOUNT_NO_REFERRAL--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_ACCOUNT_NO_REFERRAL_TITLE--}';
		$WHATs[]  = 'list_user&amp;do=norefs';
	} // END - if

	if (isExtensionActive('payout')) {
		// List new payout requests
		addSql("SELECT `userid` FROM `{?_MYSQL_PREFIX?}_user_payouts` WHERE `status`='NEW' ORDER BY `userid` ASC");
		$WHATs[]  = 'list_payouts';
		$DESCRs[] = '{--ADMIN_TASK_LIST_PAYOUTS_WAITING--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_PAYOUTS_WAITING_TITLE--}';
		addSql('SELECT `userid` FROM `{?_MYSQL_PREFIX?}_user_payouts` ORDER BY `userid` ASC');
		$WHATs[]  = 'list_payouts';
		$DESCRs[] = '{--ADMIN_TASK_LIST_PAYOUTS_ALL--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_PAYOUTS_ALL_TITLE--}';
	} // END - if

	if (isExtensionActive('wernis')) {
		// List new wernis requests
		addSql('SELECT `userid` FROM `{?_MYSQL_PREFIX?}_user_wernis` ORDER BY `userid` ASC');
		$WHATs[]  = 'list_wernis';
		$DESCRs[] = '{--ADMIN_TASK_LIST_WERNIS_ALL--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_WERNIS_ALL_TITLE--}';
	} // END - if

	if (isExtensionActive('primera')) {
		// List new primera requests
		addSql('SELECT `userid` FROM `{?_MYSQL_PREFIX?}_user_primera` ORDER BY `userid` ASC');
		$WHATs[]  = 'list_primera';
		$DESCRs[] = '{--ADMIN_TASK_LIST_PRIMERA_ALL--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_PRIMERA_ALL_TITLE--}';
	} // END - if

	if (isExtensionActive('holiday')) {
		// List holiday requests
		addSql('SELECT `userid` FROM `{?_MYSQL_PREFIX?}_user_holidays` ORDER BY `userid` ASC');
		$WHATs[]  = 'list_holiday';
		$DESCRs[] = '{--ADMIN_TASK_LIST_HOLIDAYS--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_HOLIDAYS_TITLE--}';
	} // END - if

	if (isExtensionInstalledAndNewer('bonus', '0.8.7')) {
		// List all notifications
		addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_bonus` WHERE `is_notify`='Y' ORDER BY `timestamp` DESC");
		$WHATs[]  = 'list_notifications';
		$DESCRs[] = '{--ADMIN_TASK_LIST_NOTIFICATIONS--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_NOTIFICATIONS_TITLE--}';
	} // END - if

	// Both extensions must be there
	if ((isExtensionInstalledAndNewer('bonus', '0.2.3')) && (isExtensionActive('user'))) {
		// Get more columns
		$add = runFilterChain('add_bonus_points_user_columns', '');

		// Active rallye, so add more point columns, if not empty
		$USE = '`turbo_bonus`';
		if (!empty($add)) {
			$USE = '(0' . $add . ')';
		} // END - if

		// Init variable
		$lastOnline = '';

		// Autopurge installed?
		if ((isExtensionActive('autopurge')) && (isAutopurgeInactiveEnabled()) && (getApInactiveSince() > 0)) {
			// Use last online timestamp to keep inactive members away from here
			$lastOnline   = ' AND (UNIX_TIMESTAMP() - `last_online`) < {?ap_inactive_since?}';
		} // END - if

		addSql("SELECT
	" . $USE . " AS `points`
FROM
	`{?_MYSQL_PREFIX?}_user_data`
WHERE
	`status`='CONFIRMED' AND
	" . $USE . " > 0
	" . $lastOnline . "
ORDER BY
	`points` DESC,
	`userid` ASC");
		$WHATs[]  = 'list_bonus';
		$DESCRs[] = '{--ADMIN_TASK_LIST_BONUS--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_BONUS_TITLE--}';
	}

	// Again both extensions must be there
	if ((isExtensionInstalledAndNewer('beg', '0.1.2')) && (isExtensionActive('user'))) {
		// ----- Begging rallye -----

		// Init variable
		$lastOnline = '';

		// Autopurge installed?
		if ((isExtensionActive('autopurge')) && (isAutopurgeInactiveEnabled()) && (getApInactiveSince() > 0)) {
			// Use last online timestamp to keep inactive members away from here
			$lastOnline   = ' AND (UNIX_TIMESTAMP() - `last_online`) < {?ap_inactive_since?}';
		} // END - if

		addSql("SELECT
	`userid`
FROM
	`{?_MYSQL_PREFIX?}_user_data`
WHERE
	`status`='CONFIRMED' AND
	`beg_points` > 0
	".$lastOnline."
ORDER BY
	`beg_points` DESC,
	`userid` ASC");
		$WHATs[]  = 'list_beg';
		$DESCRs[] = '{--ADMIN_TASK_LIST_BEG--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_BEG_TITLE--}';
	} // END - if

	if (isExtensionActive('doubler')) {
		// List waiting payouts
		addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_doubler` WHERE `completed`='N' ORDER BY `id` ASC");
		$WHATs[]  = 'list_doubler&amp;do=waiting&amp;select=all';
		$DESCRs[] = '{--ADMIN_TASK_LIST_DOUBLER_WAITING--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_DOUBLER_WAITING_TITLE--}';
		addSql('SELECT `id` FROM `{?_MYSQL_PREFIX?}_doubler` ORDER BY `id` ASC');
		$WHATs[]  = 'list_doubler';
		$DESCRs[] = '{--ADMIN_TASK_LIST_DOUBLER_ALL--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_DOUBLER_ALL_TITLE--}';
	} // END - if

	//
	// All referral banner
	//
	addSql('SELECT `id` FROM `{?_MYSQL_PREFIX?}_refbanner` ORDER BY `id` ASC');
	$WHATs[] = 'refbanner';
	$DESCRs[] = '{--ADMIN_TASK_LIST_REFBANNER_ALL--}';
	$TITLEs[] = '{--ADMIN_TASK_LIST_REFBANNER_ALL_TITLE--}';

	//
	// All activated referral banner
	//
	addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_refbanner` WHERE `visible`='Y' ORDER BY `id` ASC");
	$WHATs[] = 'refbanner';
	$DESCRs[] = '{--ADMIN_TASK_LIST_REFBANNER_ACTIVE--}';
	$TITLEs[] = '{--ADMIN_TASK_LIST_REFBANNER_ACTIVE_TITLE--}';

	//
	// All extensions
	//
	addSql('SELECT `id` FROM `{?_MYSQL_PREFIX?}_extensions` ORDER BY `id` ASC');
	$WHATs[] = 'extensions';
	$DESCRs[] = '{--ADMIN_TASK_LIST_EXTENSIONS_ALL--}';
	$TITLEs[] = '{--ADMIN_TASK_LIST_EXTENSIONS_ALL_TITLE--}';

	//
	// All activated extensions
	//
	addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_extensions` WHERE `ext_active`='Y' ORDER BY `id` ASC");
	$WHATs[]  = 'extensions&amp;active=Y';
	$DESCRs[] = '{--ADMIN_TASK_LIST_EXTENSIONS_ACTIVE--}';
	$TITLEs[] = '{--ADMIN_TASK_LIST_EXTENSIONS_ACTIVE_TITLE--}';

	if (isExtensionActive('sponsor')) {
		// List all sponsors
		addSql('SELECT `id` FROM `{?_MYSQL_PREFIX?}_sponsor_data` ORDER BY `id` ASC');
		$WHATs[]  = 'list_sponsor';
		$DESCRs[] = '{--ADMIN_TASK_LIST_SPONSOR--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_SPONSOR_TITLE--}';

		// List confirmed sponsor accounts
		addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_sponsor_data` WHERE `status`='CONFIRMED' ORDER BY `id` ASC");
		$WHATs[]  = 'list_sponsor';
		$DESCRs[] = '{--ADMIN_TASK_LIST_SPONSOR_CONFIRMED--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_SPONSOR_CONFIRMED_TITLE--}';

		// List unconfirmed sponsor accounts
		addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_sponsor_data` WHERE `status`='UNCONFIRMED' ORDER BY `id` ASC");
		$WHATs[]  = 'list_sponsor';
		$DESCRs[] = '{--ADMIN_TASK_LIST_SPONSOR_UNCONFIRMED--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_SPONSOR_UNCONFIRMED_TITLE--}';

		// List locked sponsor accounts
		addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_sponsor_data` WHERE `status`='LOCKED' ORDER BY `id` ASC");
		$WHATs[]  = 'list_sponsor';
		$DESCRs[] = '{--ADMIN_TASK_LIST_SPONSOR_LOCKED--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_SPONSOR_LOCKED_TITLE--}';

		// List waiting sponsor accounts to be approved
		addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_sponsor_data` WHERE `status`='PENDING' ORDER BY `id` ASC");
		$WHATs[]  = 'unlock_sponsor';
		$DESCRs[] = '{--ADMIN_TASK_LIST_SPONSOR_PENDING--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_SPONSOR_PENDING_TITLE--}';

		// Waiting payments
		addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_sponsor_orders` WHERE `pay_status`='PENDING' ORDER BY `id` ASC");
		$WHATs[]  = 'list_sponsor_pays';
		$DESCRs[] = '{--ADMIN_TASK_LIST_SPONSOR_ORDERS--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_SPONSOR_ORDERS_TITLE--}';
	} // END - if

	if (isExtensionActive('country')) {
		// List country codes
		addSql('SELECT `id` FROM `{?_MYSQL_PREFIX?}_countries` ORDER BY `id` ASC');
		$WHATs[]  = 'list_country';
		$DESCRs[] = '{--ADMIN_TASK_LIST_COUNTRY--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_COUNTRY_TITLE--}';
	} // END - if

	if (isExtensionActive('theme')) {
		// List all themes
		addSql('SELECT `id` FROM `{?_MYSQL_PREFIX?}_themes` ORDER BY `id` ASC');
		$WHATs[]  = 'theme_edit';
		$DESCRs[] = '{--ADMIN_TASK_LIST_THEME_ALL--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_THEME_ALL_TITLE--}';

		// List active themes
		addSql("SELECT `id` FROM `{?_MYSQL_PREFIX?}_themes` WHERE `theme_active`='Y' ORDER BY `id` ASC");
		$WHATs[]  = 'theme_edit';
		$DESCRs[] = '{--ADMIN_TASK_LIST_THEME_ACTIVE--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_THEME_ACTIVE_TITLE--}';
	} // END - if

	if (isExtensionActive('admins')) {
		// List all administrator logins
		addSql('SELECT `id` FROM `{?_MYSQL_PREFIX?}_admins` ORDER BY `id` ASC');
		$WHATs[]  = 'admins_edit';
		$DESCRs[] = '{--ADMIN_TASK_LIST_ADMINS_ALL--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_ADMINS_ALL_TITLE--}';
	} // END - if

	if (isExtensionActive('surfbar')) {
		// List all URLs in surfbar
		addSql('SELECT `url_id` FROM `{?_MYSQL_PREFIX?}_surfbar_urls` ORDER BY `url_id` ASC');
		$WHATs[]  = 'list_surfbar_urls';
		$DESCRs[] = '{--ADMIN_TASK_LIST_SURFBAR_URLS_ALL--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_SURFBAR_URLS_ALL_TITLE--}';

		// List all pending URLs in surfbar
		addSql("SELECT `url_id` FROM `{?_MYSQL_PREFIX?}_surfbar_urls` WHERE `url_status`='PENDING' ORDER BY `url_id` ASC");
		$WHATs[]  = 'unlock_surfbar_urls';
		$DESCRs[] = '{--ADMIN_TASK_LIST_SURFBAR_URLS_PENDING--}';
		$TITLEs[] = '{--ADMIN_TASK_LIST_SURFBAR_URLS_PENDING_TITLE--}';
	} // END - if

	// Generate extra overview rows
	$EXTRAS .= createExtraTaskRows($WHATs, $DESCRs, $TITLEs);

	// If empty just keep a forced-space left for CSS issues
	if (empty($EXTRAS)) {
		$EXTRAS = '&nbsp;';
	} // END - if

	// Add compiled string to constant for final template
	$content['extra_table'] = $EXTRAS;

	// Simply load the template... :-)
	loadTemplate('admin_overview_task', false, $content);
}

//
function createExtraTaskRows ($WHATs, $DESCRs, $TITLEs) {
	// Init variables
	$OUT = '';

	// Sadly this cannot be rewritten to a filter... :(
	foreach (getSqls() as $sqls) {
		// New format...
		foreach ($sqls as $key => $sql) {
			// Run SQL command, get line numbers and free memory
			$result = SQL_QUERY($sql, __FUNCTION__, __LINE__);

			// Prepare array for output
			$content = array(
				'row_descr' => $DESCRs[$key],
				'bottom'    => '',
			);

			// Rewrite CSS class if not last entry is reached
			if ($key < (count($sqls) - 1)) {
				$content['bottom'] = 'bottom';
			} // END - if

			if ((!SQL_HASZERONUMS($result)) && (!empty($WHATs[$key]))) {
				if (empty($TITLEs[$key])) {
					$TITLEs[$key] = '{--ADMIN_TASK_UNKNOWN_LIST_TITLE--}';
				} // END - if
				$content['row_link'] = '<a href="{%url=modules.php?module=admin&amp;what=' . $WHATs[$key] . '%}" title="' . $TITLEs[$key] . '">' . SQL_NUMROWS($result) . '</a>';
			} else {
				$content['row_link'] = '0';
			}

			// Free result
			SQL_FREERESULT($result);

			// And insert the final string into extras template
			$OUT .= loadTemplate('admin_overview_task_rows', true, $content);
		} // END- foreach
	} // END - foreach

	// Return output in the template
	return loadTemplate('admin_overview_task_extras', true, $OUT);
}

// [EOF]
?>
